@@ -9,7 +9,7 @@ class DeviceAdmin(admin.ModelAdmin):
     search_fields = ('dev_id', 'name')
     list_filter = ['is_active']
     date_hierarchy = 'modified_date'
-    readonly_fields = ('dev_id', 'reg_id')
+    # readonly_fields = ('dev_id', 'reg_id')
     actions = ['send_test_message']
 
     def send_test_message(self, request, queryset):
